import { Component, ViewChild } from '@angular/core';
import { Observable } from 'rxjs';
var AutoCompleteComponent = (function () {
    function AutoCompleteComponent() {
        this.opened = false;
        this.loading = false;
        this.searchModel = '';
    }
    AutoCompleteComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        Observable.fromEvent(this.searchRef.nativeElement, 'focus')
            .debounceTime(200)
            .subscribe(function () {
            console.log('focus');
            _this.open();
        });
        Observable.merge(Observable.fromEvent(this.searchRef.nativeElement, 'blur'), Observable.fromEvent(this.dropRef.nativeElement, 'click'))
            .debounceTime(210)
            .subscribe(function (e) {
            console.log('blur');
            if (e instanceof FocusEvent) {
                _this.cancel();
            }
        });
        var inputObs = Observable.merge(Observable.fromEvent(this.searchRef.nativeElement, 'focus'), Observable.fromEvent(this.searchRef.nativeElement, 'input'), Observable.fromEvent(this.searchRef.nativeElement, 'click'))
            .map(function (e) {
            console.log('input');
            return e.target.value;
        })
            .filter(function (value) {
            _this.data = [];
            var valid = value.length >= _this.minLength;
            if (valid) {
                _this.loading = true;
            }
            return valid;
        })
            .debounceTime(200)
            .subscribe(function (search) { return _this.search(search); });
    };
    AutoCompleteComponent.prototype.getCurrentText = function () {
        return this.current ? this.current.label || this.current.content : '';
    };
    AutoCompleteComponent.prototype.hasData = function () {
        return !!(this.data && this.data.length);
    };
    AutoCompleteComponent.prototype.isShowNoResult = function () {
        return !this.loading && !this.hasData() && !this.isShowInfo() && !this.current;
    };
    AutoCompleteComponent.prototype.isShowInfo = function () {
        var minLengthValid = (!this.searchModel || this.searchModel.length < this.minLength);
        return !this.loading && !this.hasData() && minLengthValid && !this.current && this.minLength !== 0;
    };
    AutoCompleteComponent.prototype.setData = function (data) {
        this.loading = false;
        this.data = data;
    };
    AutoCompleteComponent.prototype.reset = function () {
        this.model.control.setValue(null);
        this.current = null;
        this.searchModel = '';
        this.close();
    };
    AutoCompleteComponent.prototype.search = function (search) {
        var _this = this;
        if (this.sourceSubscription) {
            this.sourceSubscription.unsubscribe();
        }
        this.sourceSubscription = this.source(search).subscribe(function (data) {
            _this.setData(_this.map(data));
            _this.open();
        });
    };
    AutoCompleteComponent.prototype.select = function (row) {
        if (row.selectable !== false) {
            this.cancel();
            if (row) {
                this.model.control.setValue(row.id);
                this.current = row;
            }
        }
        return false;
    };
    AutoCompleteComponent.prototype.open = function () {
        if (!this.current) {
            this.opened = true;
        }
    };
    AutoCompleteComponent.prototype.close = function (clear) {
        this.opened = false;
        if (clear) {
            this.setData([]);
        }
    };
    AutoCompleteComponent.prototype.cancel = function () {
        if (this.sourceSubscription) {
            this.sourceSubscription.unsubscribe();
        }
        this.close(true);
        this.searchModel = '';
    };
    return AutoCompleteComponent;
}());
export { AutoCompleteComponent };
AutoCompleteComponent.decorators = [
    { type: Component, args: [{
                template: "<div #wrapper class=\"input-autocomplete\">\n  <input #search type=\"text\" [(ngModel)]=\"searchModel\">\n  <div class=\"input-autocomplete-current\" [hidden]=\"!current\">\n    <span>{{getCurrentText()}}</span><i class=\"fi-x\" (click)=\"reset()\"></i>\n  </div>\n  <div class=\"input-autocomplete-loader\" [hidden]=\"!loading\"></div>\n  <div #drop class=\"input-autocomplete-dropdown\" [hidden]=\"!opened\">\n    <ul class=\"input-autocomplete-list\" [hidden]=\"!hasData()\">\n      <li *ngFor=\"let row of data\" (click)=\"select(row);\"\n          [ngClass]=\"row.classes\">{{row.content}}\n      </li>\n    </ul>\n    <p [hidden]=\"!isShowNoResult()\">{{strings.noResult}}</p>\n    <p [hidden]=\"!isShowInfo()\">{{strings.help}}</p>\n  </div>\n</div>"
            },] },
];
/** @nocollapse */
AutoCompleteComponent.ctorParameters = function () { return []; };
AutoCompleteComponent.propDecorators = {
    'wrapperRef': [{ type: ViewChild, args: ['wrapper',] },],
    'searchRef': [{ type: ViewChild, args: ['search',] },],
    'dropRef': [{ type: ViewChild, args: ['drop',] },],
};
//# sourceMappingURL=autocomplete.component.js.map