import { Directive, ElementRef, Input, ViewContainerRef, ComponentFactoryResolver } from '@angular/core';
import { NgControl } from '@angular/forms';
import { AutoCompleteComponent } from './autocomplete.component';
var AutoCompleteDirective = (function () {
    function AutoCompleteDirective(view, element, resolver, model) {
        this.view = view;
        this.element = element;
        this.resolver = resolver;
        this.model = model;
        this.minLength = 3;
        this.strings = {};
        this.defaultStrings = {
            noResult: 'Aucun résultat.',
            help: 'Entrez votre recherche (2 caractères min.).'
        };
        element.nativeElement.setAttribute('type', 'hidden');
    }
    AutoCompleteDirective.prototype.ngOnInit = function () {
        var factory = this.resolver.resolveComponentFactory(AutoCompleteComponent);
        var componentRef = this.view.createComponent(factory);
        componentRef.instance.model = this.model;
        componentRef.instance.map = this.map;
        componentRef.instance.source = this.source;
        componentRef.instance.minLength = this.minLength;
        componentRef.instance.strings = Object.assign({}, this.defaultStrings, this.strings);
        this.element.nativeElement.parentElement.insertBefore(componentRef.location.nativeElement, this.element.nativeElement);
    };
    return AutoCompleteDirective;
}());
export { AutoCompleteDirective };
AutoCompleteDirective.decorators = [
    { type: Directive, args: [{
                selector: '[auto-complete]'
            },] },
];
/** @nocollapse */
AutoCompleteDirective.ctorParameters = function () { return [
    { type: ViewContainerRef, },
    { type: ElementRef, },
    { type: ComponentFactoryResolver, },
    { type: NgControl, },
]; };
AutoCompleteDirective.propDecorators = {
    'source': [{ type: Input },],
    'map': [{ type: Input },],
    'minLength': [{ type: Input },],
    'strings': [{ type: Input },],
};
//# sourceMappingURL=autocomplete.directive.js.map