import {Directive, ElementRef, Input, ViewContainerRef, ComponentFactoryResolver} from '@angular/core';
import {AutoCompleteMapFunction} from './autocomplete-map-function.type';
import {NgControl} from '@angular/forms';
import {AutoCompleteComponent} from './autocomplete.component';

@Directive({
  selector: '[auto-complete]'
})
export class AutoCompleteDirective {
  @Input() public source: Function;
  @Input() public map: AutoCompleteMapFunction;
  @Input() public minLength: number = 3;
  @Input() public strings: {
    [key: string]: string
  } = {};

  public defaultStrings: {
    [key: string]: string
  } = {
    noResult: 'Aucun résultat.',
    help: 'Entrez votre recherche (2 caractères min.).'
  };

  constructor(private view: ViewContainerRef,
              private element: ElementRef,
              private resolver: ComponentFactoryResolver,
              private model: NgControl) {
    element.nativeElement.setAttribute('type', 'hidden');
  }

  ngOnInit() {
    const factory = this.resolver.resolveComponentFactory(AutoCompleteComponent);
    const componentRef = this.view.createComponent(factory);

    componentRef.instance.model = this.model;
    componentRef.instance.map = this.map;
    componentRef.instance.source = this.source;
    componentRef.instance.minLength = this.minLength;
    componentRef.instance.strings = Object.assign({}, this.defaultStrings, this.strings);

    this.element.nativeElement.parentElement.insertBefore(componentRef.location.nativeElement, this.element.nativeElement);
  }
}